# deployment_spec

Source: [import_pkg/apps/deployment_spec.k](https://url/to/source_code/import_pkg/apps/deployment_spec.k)

This is the deployment\_spec module in kusion\_kubernetes.api.apps.v1 package.<br />This file was generated by the KCL auto-gen tool. DO NOT EDIT.<br />Editing this file might prove futile when you re-run the KCL auto-gen generate command.

## Schema DeploymentSpec

DeploymentSpec is the specification of the desired behavior of the Deployment.

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**minReadySeconds**<br />Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)|int|Undefined|optional|
|**paused**<br />Indicates that the deployment is paused.|bool|Undefined|optional|
|**progressDeadlineSeconds**<br />The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s.|int|Undefined|optional|
|**replicas**<br />Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.|int|Undefined|optional|
|**revisionHistoryLimit**<br />The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.|int|Undefined|optional|
|**selector**<br />Label selector for pods. Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment. It must match the pod template's labels.|[apis.LabelSelector](../apis/doc_label_selector_en#schema-labelselector)|Undefined|**required**|
|**strategy**<br />The deployment strategy to use to replace existing pods with new ones.|[DeploymentStrategy](doc_deployment_strategy_en#schema-deploymentstrategy)|Undefined|optional|
|**template**<br />Template describes the pods that will be created.|[core.PodTemplateSpec](../core/doc_pod_template_spec_en#schema-podtemplatespec)|Undefined|**required**|
<!-- Auto generated by kcl-doc tool, please do not edit. -->
